@@ -1302,7 +1302,7 @@ namespace PlansPlant
     {
       if( SuperTask )
       {
-	if( SuperTask->check_loop( Blockers->blockers(), Object ) )
+	if( SuperTask->check_loop( Blockers ? Blockers->blockers() : ( Object ? Object->needs() : Task::List() ), Object ) )
 	{
 	  QMessageBox::warning( this, tr( "Plans Plant" ),
 				tr( "This will create a loop in the tree.\nSelect another task as parent." ) );
@@ -1690,11 +1690,16 @@ namespace PlansPlant
   {
     bool Result = false;
     QFileDialog::Options Opt = 0;
-#ifdef Q_WS_MAEMO_5
+#ifdef PLANSPLANT_USE_QT_FILE_DIALOG
     Opt = QFileDialog::DontUseNativeDialog;
 #endif
     QString NewName = QFileDialog::getOpenFileName( this, tr( "Open file:" ), Model->file_name(),
-						    tr( "Plans Plant files" ) + " (*.plansplant);;" + tr( "All files" ) + " (*)", 0, Opt );
+#ifdef Q_WS_MAEMO_5 // Translated strings don't work
+						    "Plans Plant files (*.plansplant); All files (*)",
+#else // !Q_WS_MAEMO_5
+						    tr( "Plans Plant files" ) + " (*.plansplant);;" + tr( "All files" ) + " (*)",
+#endif // Q_WS_MAEMO_5
+						    0, Opt );
     if( !NewName.isEmpty() )
       Result = open_file( NewName );
     return Result;
@@ -1737,11 +1742,16 @@ namespace PlansPlant
     if( Model )
     {
       QFileDialog::Options Opt = 0;
-#ifdef Q_WS_MAEMO_5
+#ifdef PLANSPLANT_USE_QT_FILE_DIALOG
       Opt = QFileDialog::DontUseNativeDialog;
 #endif
       QString NewName = QFileDialog::getSaveFileName( this, tr( "Select file for saving:" ), Model->file_name(),
-						      tr( "Plans Plant files" ) + " (*.plansplant);;" + tr( "All files" ) + " (*)", 0, Opt );
+#ifdef Q_WS_MAEMO_5
+						      "Plans Plant files (*.plansplant);; All files (*)",
+#else // !Q_WS_MAEMO_5
+						      tr( "Plans Plant files" ) + " (*.plansplant);;" + tr( "All files" ) + " (*)",
+#endif // Q_WS_MAEMO_5
+						      0, Opt );
       if( !NewName.isEmpty() )
 	Result = Model->save( NewName );
       if( Result )
@@ -1759,8 +1769,10 @@ namespace PlansPlant
     {
       QString ExportName = QSettings().value( "Status/HTMLpath" ).toString();
       QFileDialog::Options Opt = 0;
-#ifdef Q_WS_MAEMO_5
+#ifdef PLANSPLANT_USE_QT_FILE_DIALOG
       Opt = QFileDialog::DontUseNativeDialog;
+#endif
+#ifdef Q_WS_MAEMO_5
       if( ExportName.isEmpty() )
 	ExportName = "/home/user/MyDocs/";
 #endif // Q_WS_MAEMO_5
@@ -1768,7 +1780,12 @@ namespace PlansPlant
       if( BaseName.isEmpty() ) BaseName = "plans";
       ExportName += BaseName + ".html";
       ExportName = QFileDialog::getSaveFileName( this, tr( "Export to HTML. Select file:" ), ExportName,
-							 tr( "HTML files" ) + " (*.html *.htm);;" + tr( "All files" ) + " (*)", 0, Opt );
+#ifdef Q_WS_MAEMO_5
+						 "HTML files (*.html *.htm);; All files (*)",
+#else // !Q_WS_MAEMO_5
+						 tr( "HTML files" ) + " (*.html *.htm);;" + tr( "All files" ) + " (*)",
+#endif // Q_WS_MAEMO_5
+						 0, Opt );
       if( !ExportName.isEmpty() )
       {
 	HTMLExportFilter Exp( ExportName );
